==> safeget-1.4.1.tar.gz: safeget-1.4.1/README.md <==

DeNova Safeget
--------------

Downloads and verifies files. It does more security checks for you
than most security experts.


If you would like a simple custom safeget for your app which embeds
all the parameters usually passed on the command line, contact
support at denova.com. It's free. Your users then run that simple small
program to download and fully verify your app, without the hassles.

Get full docs at: https://denova.com/open_source/safeget/

DeNova support gpg key:

```

-----BEGIN PGP PUBLIC KEY BLOCK-----

mQINBF2HU7MBEAC/2nRcc0yxeuOA4KdP6cWJ28f11kRLPq+fInTKT1oB+lUL4Evb
Paobc1UPi17eGxDNPccgMV+18CtJNJ6oFj9zX7CMF+AFbxHUgSJ66sNjcnW8Wg71
vyO+wv1SAcXMfzPgs54f/nH3gy8nSdItm1puYG/Cp+EzlYtEftegFYxhCtlz0OI5
kq7j3Swkh05oxeuGwO6YvAjeSdzOCJWG2xgmMLzbRxdJFBfFRGTKm3BsHcr+sUcr
KHRavh1VV2S3n2B+tj8H/uglZYFQrTgUSbtpD/JsDRBZt2oN35zqtAWUhKvqNdUz
sKaCpKB5Dstl5wFUMDboE816eXAwtCR6gIzQBfMAlDX6dmdD3ZCkI1T48llSffV8
xWWRn5MxSwOKMp1DPOGvrXeQOnkvy6IXJvl3reCj2J9NaQRIf3ZtygUSP+TnQpJ2
zXVSADqisD7eGnQJDboIlycbqgfeTeBbGW95I08fegaRu0a9SKRddGU0/pOdigiE
3bewlePAh8Y+WMWcNCbhlMi4jcvsSKDNxkKcc5PaW21kLMTDkFIRq8SOKNe9y22N
SXiDY09QLMY1DwmSjKeKIV4k4BKhdKijDrDs9DOBugEm5KebBS736U5poq8tdDJf
0kbVkpde4Qp0yLDc7jjohgmOkY4PPyMp1Cthboxey9yu8EWlMJ1a6dYIHwARAQAB
tCNEZU5vdmEgU3VwcG9ydCA8c3VwcG9ydEBkZW5vdmEuY29tPokCVAQTAQgAPhYh
BKuSGfNWMjwSfUFhthRw2+avyAF2BQJdh1OzAhsDBQkJZgGABQsJCAcCBhUICQoL
AgQWAgMBAh4BAheAAAoJEBRw2+avyAF2DPsP/Ag8gl60F1qQeR28gNab3fgQ69nz
4sOFZwJlnQGSnbS6ohYFdW4zF8fJCAykloMieztmjXUzbbt2u13a9qAZOFlMxqAn
izt/tMdn/rA4UTpc4gE33qGo4C0G59DOUFvomZF9qSS168a/nV4LZ2qaHolT6Fdt
T+kddy7/LdELB+oJVUcPgBPDe1TjUe9NF7432WBIh4dTSg439h2guTl7hSjGR+nx
fEDYyjCskUE1Q3C7AusQOqmlzr5K+mugqQv17yl/JoFcL4BmhioXQJYIoOmxNHPO
IRnPuf+fcSDsQFnILUaBunIANh+8qlCc/V2iDSSNkvYllf49TCP5UVckKe4NMond
LnuBoDlKWRv7f0+JOUQsj9Ca8vK6ZzN8ot5z2JKkC1NExn87mrAoX1Vt8cwnjHAx
AA8b52wIMn5dZXjOhKmS56SuwbryfHaSWUdsWPN+bTgusqHlKjNwGwt3sgqHwjta
8LwDYs40OhiUFS72Bw+BFJMu962X9u/NXB/i0uyf63dPidVw/QWXH8qn0YSHUwyW
nYt4gyc5ZjPq+hrBMkp45Hsigz+20+oGFc0H05BW2OO8BcMzLQQgsyeh4mEmnI7S
pn1JrLbFSQFwWAWl4CYuJHdeAt3cBo+Vwof3pPZ1CtRKy92fn90Z98HUnrgDXNBs
DBzmySeX2nvN1LYd
=4YCw
-----END PGP PUBLIC KEY BLOCK-----

```

==> safeget-1.4.3.tar.gz: safeget-1.4.3/README.md <==

DeNova Safeget
--------------

Downloads and verifies files. It does more security checks for you
than most security experts.


If you would like a simple custom safeget for your app which embeds
all the parameters usually passed on the command line, contact
support at denova.com. It's free. Your users then run that simple small
program to download and fully verify your app, without the hassles.

Safeget requires python3. If you see a "SyntaxError: invalid syntax",
then you probably are tryinng to run safeget with python2.

Get full docs at: https://denova.com/open_source/safeget/


DeNova support gpg key
----------------------

```

-----BEGIN PGP PUBLIC KEY BLOCK-----

mQINBF2HU7MBEAC/2nRcc0yxeuOA4KdP6cWJ28f11kRLPq+fInTKT1oB+lUL4Evb
Paobc1UPi17eGxDNPccgMV+18CtJNJ6oFj9zX7CMF+AFbxHUgSJ66sNjcnW8Wg71
vyO+wv1SAcXMfzPgs54f/nH3gy8nSdItm1puYG/Cp+EzlYtEftegFYxhCtlz0OI5
kq7j3Swkh05oxeuGwO6YvAjeSdzOCJWG2xgmMLzbRxdJFBfFRGTKm3BsHcr+sUcr
KHRavh1VV2S3n2B+tj8H/uglZYFQrTgUSbtpD/JsDRBZt2oN35zqtAWUhKvqNdUz
sKaCpKB5Dstl5wFUMDboE816eXAwtCR6gIzQBfMAlDX6dmdD3ZCkI1T48llSffV8
xWWRn5MxSwOKMp1DPOGvrXeQOnkvy6IXJvl3reCj2J9NaQRIf3ZtygUSP+TnQpJ2
zXVSADqisD7eGnQJDboIlycbqgfeTeBbGW95I08fegaRu0a9SKRddGU0/pOdigiE
3bewlePAh8Y+WMWcNCbhlMi4jcvsSKDNxkKcc5PaW21kLMTDkFIRq8SOKNe9y22N
SXiDY09QLMY1DwmSjKeKIV4k4BKhdKijDrDs9DOBugEm5KebBS736U5poq8tdDJf
0kbVkpde4Qp0yLDc7jjohgmOkY4PPyMp1Cthboxey9yu8EWlMJ1a6dYIHwARAQAB
tCNEZU5vdmEgU3VwcG9ydCA8c3VwcG9ydEBkZW5vdmEuY29tPokCVAQTAQgAPhYh
BKuSGfNWMjwSfUFhthRw2+avyAF2BQJdh1OzAhsDBQkJZgGABQsJCAcCBhUICQoL
AgQWAgMBAh4BAheAAAoJEBRw2+avyAF2DPsP/Ag8gl60F1qQeR28gNab3fgQ69nz
4sOFZwJlnQGSnbS6ohYFdW4zF8fJCAykloMieztmjXUzbbt2u13a9qAZOFlMxqAn
izt/tMdn/rA4UTpc4gE33qGo4C0G59DOUFvomZF9qSS168a/nV4LZ2qaHolT6Fdt
T+kddy7/LdELB+oJVUcPgBPDe1TjUe9NF7432WBIh4dTSg439h2guTl7hSjGR+nx
fEDYyjCskUE1Q3C7AusQOqmlzr5K+mugqQv17yl/JoFcL4BmhioXQJYIoOmxNHPO
IRnPuf+fcSDsQFnILUaBunIANh+8qlCc/V2iDSSNkvYllf49TCP5UVckKe4NMond
LnuBoDlKWRv7f0+JOUQsj9Ca8vK6ZzN8ot5z2JKkC1NExn87mrAoX1Vt8cwnjHAx
AA8b52wIMn5dZXjOhKmS56SuwbryfHaSWUdsWPN+bTgusqHlKjNwGwt3sgqHwjta
8LwDYs40OhiUFS72Bw+BFJMu962X9u/NXB/i0uyf63dPidVw/QWXH8qn0YSHUwyW
nYt4gyc5ZjPq+hrBMkp45Hsigz+20+oGFc0H05BW2OO8BcMzLQQgsyeh4mEmnI7S
pn1JrLbFSQFwWAWl4CYuJHdeAt3cBo+Vwof3pPZ1CtRKy92fn90Z98HUnrgDXNBs
DBzmySeX2nvN1LYd
=4YCw
-----END PGP PUBLIC KEY BLOCK-----

```
